==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/CustomContourValueResolverDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CustomContourValueResolverEventArgsDescriptionMetadata } from "./CustomContourValueResolverEventArgsDescriptionMetadata";
import { ContourValueResolverDescriptionMetadata } from "./ContourValueResolverDescriptionMetadata";
import { CustomContourValueResolverDescription } from "./CustomContourValueResolverDescription";
/**
 * @hidden
 */
var CustomContourValueResolverDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CustomContourValueResolverDescriptionMetadata, _super);
    function CustomContourValueResolverDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CustomContourValueResolverDescriptionMetadata.b = function (a) {
        if (CustomContourValueResolverDescriptionMetadata.a == null) {
            CustomContourValueResolverDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CustomContourValueResolverDescriptionMetadata.c(CustomContourValueResolverDescriptionMetadata.a);
        }
        if (a.g(CustomContourValueResolverDescriptionMetadata.a)) {
            return;
        }
        a.s(CustomContourValueResolverDescriptionMetadata.a);
        CustomContourValueResolverEventArgsDescriptionMetadata.d(a);
    };
    CustomContourValueResolverDescriptionMetadata.c = function (a) {
        ContourValueResolverDescriptionMetadata.c(a);
        a.item("GetCustomContourValuesRef", "EventRef::getCustomContourValues");
    };
    CustomContourValueResolverDescriptionMetadata.d = function (a) {
        CustomContourValueResolverDescriptionMetadata.b(a);
        a.u("CustomContourValueResolver", function () { return new CustomContourValueResolverDescription(); });
        a.t("CustomContourValueResolver", CustomContourValueResolverDescriptionMetadata.a);
    };
    CustomContourValueResolverDescriptionMetadata.$t = markType(CustomContourValueResolverDescriptionMetadata, 'CustomContourValueResolverDescriptionMetadata');
    CustomContourValueResolverDescriptionMetadata.a = null;
    return CustomContourValueResolverDescriptionMetadata;
}(Base));
export { CustomContourValueResolverDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CustomContourValueResolverDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CustomContourValueResolverEventArgsDescriptionMetadata } from "./CustomContourValueResolverEventArgsDescriptionMetadata";
import { ContourValueResolverDescriptionMetadata } from "./ContourValueResolverDescriptionMetadata";
import { CustomContourValueResolverDescription } from "./CustomContourValueResolverDescription";
/**
 * @hidden
 */
var CustomContourValueResolverDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CustomContourValueResolverDescriptionMetadata, _super);
    function CustomContourValueResolverDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CustomContourValueResolverDescriptionMetadata.b = function (a) {
        if (CustomContourValueResolverDescriptionMetadata.a == null) {
            CustomContourValueResolverDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CustomContourValueResolverDescriptionMetadata.c(CustomContourValueResolverDescriptionMetadata.a);
        }
        if (a.j(CustomContourValueResolverDescriptionMetadata.a)) {
            return;
        }
        a.y(CustomContourValueResolverDescriptionMetadata.a);
        CustomContourValueResolverEventArgsDescriptionMetadata.d(a);
    };
    CustomContourValueResolverDescriptionMetadata.c = function (a) {
        ContourValueResolverDescriptionMetadata.c(a);
        a.item("GetCustomContourValuesRef", "EventRef::getCustomContourValues");
    };
    CustomContourValueResolverDescriptionMetadata.d = function (a) {
        CustomContourValueResolverDescriptionMetadata.b(a);
        a.aa("CustomContourValueResolver", function () { return new CustomContourValueResolverDescription(); });
        a.z("CustomContourValueResolver", CustomContourValueResolverDescriptionMetadata.a);
    };
    CustomContourValueResolverDescriptionMetadata.$t = markType(CustomContourValueResolverDescriptionMetadata, 'CustomContourValueResolverDescriptionMetadata');
    CustomContourValueResolverDescriptionMetadata.a = null;
    return CustomContourValueResolverDescriptionMetadata;
}(Base));
export { CustomContourValueResolverDescriptionMetadata };
